package Lire::Config::ChartTypeSpec;

use strict;

=pod

=head1 NAME

Lire::Config::ChartTypeSpec - PluginSpec for ChartType.

=head1 DESCRIPTION

This is a Lire::Config::PluginSpec object that can be used to select
any registered Lire::ChartType.

=cut

use base qw/Lire::Config::BasePluginSpec/;

sub plugin_type {
    return "chart_type";
}

1;

__END__

=pod

=head1 VERSION

$Id: ChartTypeSpec.pm,v 1.2 2006/07/23 13:16:30 vanbaal Exp $

=head1 AUTHOR

  Francis J. Lacoste <flacoste@logreport.org>

=head1 COPYRIGHT

Copyright (C) 2004  Stichting LogReport Foundation LogReport@LogReport.org

This file is part of Lire.

Lire is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program (see COPYING); if not, check with
http://www.gnu.org/copyleft/gpl.html.

=cut
